# remirepo/fedora spec file for php-tracy
#
# Copyright (c) 2015-2018 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    bcb93a9d4347be8779c83b200b64ea6f52d6f9ed
#global gh_date      20150728
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     nette
%global gh_project   tracy
%global ns_vendor    Tracy
%global php_home     %{_datadir}/php
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_project}
Version:        2.4.11
%global specrel 1
Release:        %{?gh_date:1%{specrel}.%{?prever}%{!?prever:%{gh_date}git%{gh_short}}}%{!?gh_date:%{specrel}}%{?dist}.1
Summary:        Tracy: useful PHP debugger

Group:          Development/Libraries
License:        BSD or GPLv2 or GPLv3
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{gh_short}.tgz
# pull a git snapshot to get test sutie
Source1:        makesrc.sh

BuildArch:      noarch
BuildRequires:  php-composer(theseer/autoload)
%if %{with_tests}
BuildRequires:  php(language) >= 5.4.4
BuildRequires:  php-session
BuildRequires:  php-json
BuildRequires:  php-date
BuildRequires:  php-iconv
BuildRequires:  php-pcre
BuildRequires:  php-posix
BuildRequires:  php-reflection
BuildRequires:  php-spl
# From composer.json, "require-dev": {
#        "nette/di": "~2.3",
#        "nette/tester": "~2.0"
BuildRequires:  php-composer(%{gh_owner}/di) >= 2.3
BuildRequires:  php-composer(%{gh_owner}/tester) >= 1.7
%endif

# from composer.json, "require": {
#               "php": ">=5.4.4",
#               "ext-session": "*",
#               "ext-json": "*"
Requires:       php(language) >= 5.4.4
Requires:       php-session
Requires:       php-json
# from phpcompatinfo report for version 2.3.5, XDebug is optional
Requires:       php-date
Requires:       php-iconv
Requires:       php-pcre
Requires:       php-posix
Requires:       php-reflection
Requires:       php-spl

# provides tracy/tracy
Provides:       php-composer(%{gh_project}/%{gh_project}) = %{version}


%description
Tracy library is a useful PHP everyday programmer's helper. It helps you to:

- quickly detect and correct errors
- log errors
- dump variables
- measure the time

To use this library, you just have to add, in your project:
  require_once '%{php_home}/%{ns_vendor}/autoload.php';


%prep
%setup -q -n %{gh_project}-%{gh_commit}

# drop upstream autoloader which is outside tree
rm src/tracy.php
# move
mv src/shortcuts.php src/%{ns_vendor}
mv src/Bridges       src/%{ns_vendor}


%build
: Generate a classmap autoloader
phpab --output src/%{ns_vendor}/autoload.php src

cat << 'EOF' | tee -a src/%{ns_vendor}/autoload.php
require_once __DIR__ . '/shortcuts.php';
EOF


%install
mkdir -p     %{buildroot}%{php_home}
cp -pr src/* %{buildroot}%{php_home}/


%check
%if %{with_tests}
export LANG=fr_FR.utf8

: Generate autoloader
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{php_home}/Tester/autoload.php';
require_once '%{php_home}/Nette/DI/autoload.php';
require_once '%{buildroot}%{php_home}/%{ns_vendor}/autoload.php';
EOF

: Run test suite in sources tree
ret=0
# PHP 7.1/7.2: Fatal error: Unknown: Cannot use output buffering in output buffering display handlers in Unknown on line 0
# In local build, OK in mock
for cmd in php php56 php70 php71 php72; do
  if which $cmd; then
   $cmd %{_bindir}/nette-tester --colors 0 -p $cmd -C tests  -d serialize_precision=14 -s || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license license.md
%doc readme.md contributing.md
%doc composer.json
%{php_home}/%{ns_vendor}


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.11-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb  2 2018 Remi Collet <remi@remirepo.net> - 2.4.11-1
- Update to 2.4.11

* Fri Oct  6 2017 Remi Collet <remi@remirepo.net> - 2.4.10-1
- Update to 2.4.10

* Thu Aug 17 2017 Remi Collet <remi@remirepo.net> - 2.4.9-1
- Update to 2.4.9

* Sat Aug  5 2017 Remi Collet <remi@remirepo.net> - 2.4.8-1
- Update to 2.4.8

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.7-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu May 11 2017 Remi Collet <remi@remirepo.net> - 2.4.7-1
- Update to 2.4.7

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.6-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Jan 30 2017 Remi Collet <remi@fedoraproject.org> - 2.4.6-1
- update to 2.4.6

* Sun Jan 15 2017 Remi Collet <remi@fedoraproject.org> - 2.4.5-1
- update to 2.4.5

* Sat Dec 10 2016 Remi Collet <remi@fedoraproject.org> - 2.4.4-1
- update to 2.4.4

* Wed Nov 23 2016 Remi Collet <remi@fedoraproject.org> - 2.4.3-2
- set serialize_precision=14, fix FTBFS with php 7.1

* Fri Sep 30 2016 Remi Collet <remi@fedoraproject.org> - 2.4.3-1
- update to 2.4.3

* Tue Aug  2 2016 Remi Collet <remi@fedoraproject.org> - 2.4.2-1
- update to 2.4.2
- raise dependency on PHP >= 5.4.4

* Mon May 30 2016 Remi Collet <remi@fedoraproject.org> - 2.3.11-1
- update to 2.3.11

* Mon Feb 29 2016 Remi Collet <remi@fedoraproject.org> - 2.3.10-1
- update to 2.3.10

* Mon Feb 22 2016 Remi Collet <remi@fedoraproject.org> - 2.3.9-1
- update to 2.3.9

* Sun Feb 14 2016 Remi Collet <remi@fedoraproject.org> - 2.3.8-1
- update to 2.3.8
- add upstream patch for new PHP

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.7-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 30 2015 Remi Collet <remi@fedoraproject.org> - 2.3.7-1
- update to 2.3.7

* Thu Oct 29 2015 Remi Collet <remi@fedoraproject.org> - 2.3.6-1
- update to 2.3.6

* Tue Oct 20 2015 Remi Collet <remi@fedoraproject.org> - 2.3.5-1
- initial package